@@ -5,18 +5,38 @@ import hashlib
 
 from django import template
 from django import urls
-from django.utils.html import format_html
 from django.utils.http import urlencode
+from django.utils.html import escape, format_html
 from django.template import loader
 from django.template.defaultfilters import stringfilter
+from django.utils.safestring import mark_safe
 
 register = template.Library()
 
+
 @register.filter
 @stringfilter
 def make_id(value):
     """Generate an ID given a string, to use as element IDs in HTML"""
-    return hashlib.sha1(value.encode('utf-8')).hexdigest()
+    return hashlib.sha1(value.encode("utf-8")).hexdigest()
+
+
+@register.filter()
+@stringfilter
+def search_highlight(value, search):
+    """Surround the section of text matching the search with a classed span"""
+    if search == "":
+        return value
+    try:
+        pos = value.lower().index(search.lower())
+        start = escape(value[:pos])
+        match = escape(value[pos:pos+len(search)])
+        end = escape(value[pos+len(search):])
+        return mark_safe(f"{start}<span class=\"highlight\">{match}</span>{end}")
+    except ValueError:
+        pass
+    return value
+
 
 @register.simple_tag
 def autocomplete(name, selected=None):
@@ -33,20 +53,23 @@ def autocomplete(name, selected=None):
                     Defaults to None
 
     """
-    options_selected = ','.join(
-        [str(x) for x in selected]) if selected is not None else ''
+    options_selected = (
+        ",".join([str(x) for x in selected]) if selected is not None else ""
+    )
 
-    url = urls.reverse(name, kwargs={'method': 'component'})
+    url = urls.reverse(name, kwargs={"method": "component"})
     parameter = urlencode({name: options_selected})
     get_url = f"{url}?{parameter}"
 
-    return format_html((
-        "<div "
-            f"hx-get=\"{get_url}\""
-            "hx-trigger=\"load\""
-            "hx-swap=\"outerHTML\">"
-        "</div>"
-    ))
+    return format_html(
+        (
+            "<div "
+            f'hx-get="{get_url}"'
+            'hx-trigger="load"'
+            'hx-swap="outerHTML">'
+            "</div>"
+        )
+    )
 
 
 @register.simple_tag
@@ -59,8 +82,8 @@ def autocomplete_head(bootstrap=False):
         bootstrap   Set to true if the bootstrap css should be loaded from cdn
                     Defaults to False.
     """
-    return loader.get_template('autocomplete/head.html', using="django").render(
-        {'bootstrap': bootstrap}
+    return loader.get_template("autocomplete/head.html", using="django").render(
+        {"bootstrap": bootstrap}
     )
 
 
@@ -81,11 +104,11 @@ def autocomplete_scripts(context, bootstrap=False, htmx=False, htmx_csrf=False):
                     Defaults to False.
 
     """
-    return loader.get_template('autocomplete/scripts.html', using="django"). \
-        render({
-            'csrf_token': context.get('csrf_token', ''),
-            'bootstrap': bootstrap,
-            'htmx': htmx,
-            'htmx_csrf': htmx_csrf,
+    return loader.get_template("autocomplete/scripts.html", using="django").render(
+        {
+            "csrf_token": context.get("csrf_token", ""),
+            "bootstrap": bootstrap,
+            "htmx": htmx,
+            "htmx_csrf": htmx_csrf,
         }
     )
